# SPDX-FileCopyrightText: 2021 Dimitris Kardarakos <dimkard@posteo.net>
# SPDX-License-Identifier: GPL-3.0-or-later

from abc import ABC, abstractmethod


class AbstractPracticeStrategy(ABC):
    """Abstract class that represents the interface that
    different practice strategies should implement
    """

    @property
    @abstractmethod
    def currentChallengeQuestion(self):
        """Returns the question data of the current challenge. The returned type
        should be a ChallengeQuestion dataclass derivative converted to dictionary
        """

    @property
    @abstractmethod
    def practiceProgress(self):
        """Returns the percentage of the practice session that has been completed
        """

    @property
    @abstractmethod
    def challengesAnswered(self):
        """Returns the amount of challenges already answered in the current
        practice session
        """

    @abstractmethod
    def startPractice(self, course_name, skill_id, skill_name,
                      skill_words, skill_phrases, user_stats):
        """Executes the required initialization steps needed for a practice
        session for a specific skill to be started
        """

    @abstractmethod
    def loadChallenge(self):
        """If there are remaining challenges in the practice session, it
        initializes the challenge to be offered to the user, e.g. currentChallengeQuestion
        should be set accordingly. Returns True if such a challenge exists.
        """

    @abstractmethod
    def checkResult(self, answer_given):
        """Returns True if the answer given is the correct one for the current
        challenge
        """

    @abstractmethod
    def updateStats(self):
        """Updates the statistics object that represents the progress of a user
        for the skill being practiced
        """
