#!/usr/bin/env python3

# SPDX-FileCopyrightText: 2021 Dimitris Kardarakos <dimkard@posteo.net>
# SPDX-License-Identifier: GPL-3.0-or-later

from PySide2.QtGui import QGuiApplication
from PySide2.QtCore import QUrl
from PySide2.QtQml import QQmlApplicationEngine, qmlRegisterType
from glossaico.q_modules_model import QModulesModel
from glossaico.q_skills_model import QSkillsModel
from glossaico.q_language_course import QLanguageCourse
from glossaico.q_practice_context import QPracticeContext
from glossaico.q_config_singleton_adapter import QConfigSingletonAdapter
from glossaico.q_data_controller import QDataController
from glossaico.simple_practice_strategy import SimplePracticeStrategy
from glossaico.q_app_info import QAppInfo


def main():
    """Initializes and manages the application execution"""
    app = QGuiApplication()
    engine = QQmlApplicationEngine()

    qmlRegisterType(QModulesModel, 'org.codeberg.dimkard.glossaico',
                    1, 0, 'QModulesModel')
    qmlRegisterType(QSkillsModel, 'org.codeberg.dimkard.glossaico',
                    1, 0, 'QSkillsModel')
    qmlRegisterType(QLanguageCourse, 'org.codeberg.dimkard.glossaico',
                    1, 0, 'QLanguageCourse')

    config_ctl = QConfigSingletonAdapter.getInstance()
    data_ctl = QDataController.getInstance()
    practice_strategy = SimplePracticeStrategy()
    practice_ctx = QPracticeContext(practice_strategy)
    q_app_info = QAppInfo.getInstance()

    context = engine.rootContext()
    # TODO: On QT6 make them singletons
    context.setContextProperty("QPracticeContext", practice_ctx)
    context.setContextProperty("QConfigSingletonAdapter", config_ctl)
    context.setContextProperty("QDataController", data_ctl)
    context.setContextProperty("QAppInfo", q_app_info)

    base_path = config_ctl.readApplicationDirectory()
    url = QUrl(f'file://{base_path}/qml/main.qml')
    engine.load(url)

    if len(engine.rootObjects()) == 0:
        quit()

    app.exec_()

if __name__ == "__main__":
    main()
