# SPDX-FileCopyrightText: 2021 Dimitris Kardarakos <dimkard@posteo.net>
# SPDX-License-Identifier: GPL-3.0-or-later

from PySide2.QtCore import QObject, Property
from glossaico.q_config_singleton_adapter import QConfigSingletonAdapter
from glossaico import (APP_NAME, APP_COMPONENT_NAME, APP_AUTHOR, APP_AUTHOR_EMAIL,
                       APP_DESCRIPTION, APP_URL, APP_BUG_URL, APP_VERSION,
                       APP_COPYRIGHT, APP_AUTHOR_WEB_ADDR, APP_CREDITS
                       )


class QAppInfo(QObject):
    """Class that returns application metadata"""
    _instance = None

    def __init__(self):
        if QAppInfo._instance:
            raise Exception("QAppInfo is a singleton class")

        QAppInfo._instance = self
        QObject.__init__(self)

        self._cfg = QConfigSingletonAdapter.getInstance()
        self._data = {
            "displayName": APP_NAME,
            "componentName": APP_COMPONENT_NAME,
            "shortDescription": APP_DESCRIPTION,
            "homepage": APP_URL,
            "bugAddress": APP_BUG_URL,
            "version": APP_VERSION,
            "programLogo": "{}/icons/mascot-jetpack-noshadow.svg".format(
                self._cfg.applicationDirectory),
            "authors": [
                {
                    "name": APP_AUTHOR,
                    "emailAddress": APP_AUTHOR_EMAIL,
                    "webAddress": APP_AUTHOR_WEB_ADDR
                }
            ],
            "credits": APP_CREDITS,
            "translators": [],
            "licenses": [
                {
                    "name": "GPL-3.0-or-later",
                    "text": "",
                    "spdx": "GPL-3.0-or-later"
                }
            ],
            "copyrightStatement": APP_COPYRIGHT,
            "desktopFileName": "org.codeberg.dimkard.glossaico.desktop",
            "otherText": ""
        }

        with open("{}/data/GPL-3.0-or-later.txt".
                  format(self._cfg.applicationDirectory), 'r') as file:
            self._data["licenses"][0]["text"] = file.read()

    @staticmethod
    def getInstance():
        """Returns the single object that can be instantiated"""
        if not QAppInfo._instance:
            QAppInfo()

        return QAppInfo._instance

    def readAboutData(self):
        """Returns the variant map that represents the about-data information
        of the application which is needed by the QML side
        """
        return self._data

    aboutData = Property("QVariantMap", readAboutData, constant=True)
