/*
 * SPDX-FileCopyrightText: 2021 Dimitris Kardarakos <dimkard@posteo.net>
 *
 * SPDX-License-Identifier: GPL-3.0-or-later
 */

import QtQuick 2.12
import QtMultimedia 5.12
import QtQuick.Controls 2.12 as Controls
import QtQuick.Layouts 1.12
import org.kde.kirigami 2.12 as Kirigami
import org.codeberg.dimkard.glossaico 1.0 as Glossaico

Kirigami.ScrollablePage {
    id: root

    property int returnAnswerCode: 0
    property var challengeItem
    property var challengeData
    property var answerGiven: { "answer": null }
    property var specialCharacters: []
    property real progress
    property bool preventNavigation: true

    Audio {
        id: answerSound

        property string audioName: "correct"

        source: QConfigSingletonAdapter.applicationDirectory + "/sound/" + audioName + ".mp3"
    }


    header: Item {
        id: headerItem

        implicitHeight: Kirigami.Units.gridUnit * 2

        Controls.ProgressBar {
            anchors.centerIn: parent

            from: 0
            to: 1
            value: root.progress
            width: root.width - (Kirigami.Units.gridUnit * 2)
        }
    }

    footer: Kirigami.InlineMessage {
        id: footerMessage

        text: ""
        visible: true
        icon.name: QConfigSingletonAdapter.applicationDirectory + "/icons/mascot-jetpack-noshadow.svg"

        actions: [
            Kirigami.Action {
                text: qsTr("Finish early")
                visible: root.state === ""

                onTriggered: QPracticeContext.finalizeSession()
            },

            Kirigami.Action {
                text: qsTr("Skip")
                visible: root.state === ""

                onTriggered: QPracticeContext.completeChallenge()
            },

            Kirigami.Action {
                text: qsTr("Submit")
                visible: root.state === ""
                enabled: root.answerGiven && root.answerGiven["answer"] && root.answerGiven["answer"].length > 0

                onTriggered: root.state = QPracticeContext.checkResult(answerGiven) ? "answered-correct" : "answered-wrong"
            },

            Kirigami.Action {
                text: qsTr("Continue")
                visible: root.state !== ""

                onTriggered: QPracticeContext.completeChallenge()
            }
        ]
    }

    states: [
        State {
            name: ""
            PropertyChanges {target: footerMessage; text: ""; type: Kirigami.MessageType.Information}
            PropertyChanges {target: root; returnAnswerCode: 0}
            PropertyChanges {target: challengeItem; enabled: true}
        },
        State {
            name: "answered-correct"
            PropertyChanges {target: footerMessage; text: qsTr("Correct answer!"); type: Kirigami.MessageType.Positive}
            PropertyChanges {target: root; returnAnswerCode: 1}
            PropertyChanges {target: challengeItem; enabled: false}
            PropertyChanges {target: answerSound; audioName: "correct"}
            StateChangeScript {
                name: "playAudio"
                script: if(!QConfigSingletonAdapter.silentMode) answerSound.play()
            }
        },
        State {
            name: "answered-wrong"
            PropertyChanges {target: footerMessage;  text: qsTr("Wrong answer!"); type: Kirigami.MessageType.Error}
            PropertyChanges {target: root; returnAnswerCode: -1}
            PropertyChanges {target: challengeItem; enabled: false}
            PropertyChanges {target: answerSound; audioName: "wrong"}
            StateChangeScript {
                name: "playAudio"
                script: if(!QConfigSingletonAdapter.silentMode) answerSound.play()
            }
        }
    ]
}
