/*
 * SPDX-FileCopyrightText: 2021 Dimitris Kardarakos <dimkard@posteo.net>
 *
 * SPDX-License-Identifier: GPL-3.0-or-later
 */

import QtQuick 2.12
import QtQuick.Controls 2.12 as Controls
import QtQuick.Layouts 1.12
import QtMultimedia 5.12
import org.kde.kirigami 2.12 as Kirigami

Kirigami.Page {
    id: root

    property int challengesAnswered: 0

    title: qsTr("Lesson finished")

    signal sessionEnd()

    Audio {
        id: audio

        source: QConfigSingletonAdapter.applicationDirectory + "/sound/fanfare.mp3"
    }

    ColumnLayout {
        anchors {
            left: parent.left
            right: parent.right
            top: parent.top
        }

        spacing: Kirigami.Units.largeSpacing

        RowLayout {
            spacing: Kirigami.Units.largeSpacing

            Image {
                source: QConfigSingletonAdapter.applicationDirectory + "/icons/mascot-jetpack-noshadow"

                Layout.maximumHeight: Kirigami.Units.iconSizes.enormous
                Layout.preferredWidth: height
            }

            Kirigami.Heading {
                id: loaderHeader

                text: root.challengesAnswered > 0 ? qsTr("Lesson finished. You have completed %1 challenges!").arg(root.challengesAnswered) : qsTr("Lesson skipped.")
                wrapMode: Text.WordWrap
                level: 1

                Layout.fillWidth: true

            }

            Layout.fillWidth: true
        }
    }

    Component.onCompleted: {
        if(!QConfigSingletonAdapter.silentMode && (root.challengesAnswered > 0)) {
            audio.play()
        }
    }

    footer: Kirigami.InlineMessage {
        id: continueButton

        text: ""
        visible: true
        icon.name: QConfigSingletonAdapter.applicationDirectory + "/icons/mascot-jetpack-noshadow.svg"

        actions: [
            Kirigami.Action {
                text: qsTr("Continue")

                onTriggered: root.sessionEnd()
            }
        ]
    }
}
