/*
 * SPDX-FileCopyrightText: 2021 Dimitris Kardarakos <dimkard@posteo.net>
 *
 * SPDX-License-Identifier: GPL-3.0-or-later
 */

import QtQuick 2.12
import QtQuick.Controls 2.12 as Controls
import QtQuick.Layouts 1.12
import QtQml.Models 2.15
import org.kde.kirigami 2.12 as Kirigami

Kirigami.ScrollablePage {
    id: root

    property bool showGlobalHandle: true
    property string selectedTargetLanguage: ""
    property var course

    title: qsTr("Courses")

    signal courseLoaded

    Kirigami.CardsListView {
        id: view

        model: coursesModel
        header: Kirigami.Heading {
            text: qsTr("Select course")
            width: parent.width
            wrapMode: Text.WordWrap
            topPadding: Kirigami.Units.smallSpacing
            leftPadding: Kirigami.Units.smallSpacing
        }

        delegate: Kirigami.AbstractCard {
            id: courseCard

            showClickFeedback: true

            header: Kirigami.Heading {
                text: model && model.targetLanguage
                wrapMode: Text.WordWrap
            }

            contentItem: Controls.Label {
                wrapMode: Text.WordWrap
                text: model && model.description
            }

            onClicked: {
                root.state = "busy"
                course.load(model.name)
            }
        }
    }

    Connections {
        target: root.course

        function onLoaded() {
            root.courseLoaded()
        }
    }

    RowLayout {
        id: downloadProgress

        anchors {
            bottom: parent.bottom
            right: parent.right
            left: parent.left
            margins: Kirigami.Units.largeSpacing
        }
        visible: false
        spacing: Kirigami.Units.largeSpacing

        Controls.Label {
            id: downloadingFile

            text: qsTr("Loading course data")
        }

        Controls.ProgressBar {
            id: progressBar

            from: 0
            to: 100
            value: timer.value

            Layout.fillWidth: true
        }
    }

    Timer {
        id: timer

        property int value: 0

        interval: 80
        repeat: true
        running: true

        onTriggered: {
            value = (value + 1) % 100
        }
    }

    ListModel {
        id: coursesModel

        ListElement {
            name: "spanish-from-english"
            targetLanguage: "Spanish"
            description: "Spanish course for English speakers"
        }

        ListElement {
            name: "german-from-english"
            targetLanguage: "German"
            description: "German course for English speakers"
        }

        ListElement {
            name: "basque-from-english"
            targetLanguage: "Basque"
            description: "Basque course for English speakers"
        }

    }

    states: [
        State {
            name: ""
            PropertyChanges {target: view; enabled: true}
            PropertyChanges {target: root; showGlobalHandle: true}
            PropertyChanges {target: downloadProgress; visible: false}
        },
        State {
            name: "busy"
            PropertyChanges {target: view; enabled: false}
            PropertyChanges {target: root; showGlobalHandle: false}
            PropertyChanges {target: downloadProgress; visible: true}
        }
    ]
}
