/*
 * SPDX-FileCopyrightText: 2021 Dimitris Kardarakos <dimkard@posteo.net>
 *
 * SPDX-License-Identifier: GPL-3.0-or-later
 */

import QtQuick 2.12
import QtQuick.Controls 2.12 as Controls
import QtQuick.Layouts 1.12
import org.kde.kirigami 2.12 as Kirigami

Kirigami.Page {
    id: root

    title: qsTr("Welcome to Glossaico")

    signal imagesLoaded()

    ColumnLayout {
        anchors.fill: parent

        width: parent.width
        spacing: Kirigami.Units.largeSpacing * 2

        RowLayout {
            id: info

            spacing: Kirigami.Units.largeSpacing

            Image {
                source: QConfigSingletonAdapter.applicationDirectory + "/icons/mascot-jetpack-noshadow"

                Layout.maximumHeight: Kirigami.Units.iconSizes.huge
                Layout.preferredWidth: height
            }

            Kirigami.Heading {
                id: loaderHeader

                text: qsTr("The language courses use images provided by unsplash. Please press <i>Download</i> to continue. It will take some time...")
                wrapMode: Text.WordWrap
                level: 3

                Layout.fillWidth: true

            }

            Layout.fillWidth: true
        }

        Item {
            Layout.fillHeight: true
        }

        RowLayout {
            spacing: Kirigami.Units.largeSpacing

            Controls.Label {
                id: downloadingFile
                visible: false

                text: qsTr("Fetching %1").arg(QDataController.activeDownloadName)
            }

            Controls.ProgressBar {
                id: progressBar

                visible: false
                from: 0
                to: 100
                value: timer.value

                Layout.fillWidth: true
            }

            Layout.fillWidth: true
        }

        Controls.Label {
            id: unsplashLicense

            text: qsTr("Unsplash photos are made to be used freely. <html><a href='https://unsplash.com/license'>License information</a></html> ")
            wrapMode: Text.WordWrap
            horizontalAlignment: Qt.AlignHCenter

            Layout.fillWidth: true

            onLinkActivated: Qt.openUrlExternally(link)
        }
    }

    Timer {
        id: timer

        property int value: 0

        interval: 80
        repeat: true
        running: true

        onTriggered: {
            value = (value + 1) % 100
        }
    }

    footer: Kirigami.InlineMessage {
        id: downloadMessage

        text: ""
        visible: true
        icon.name: QConfigSingletonAdapter.applicationDirectory + "/icons/mascot-jetpack-noshadow.svg"

        actions: [
            Kirigami.Action {
                text: qsTr("Download")

                onTriggered: {
                    root.state = "downloading"
                    QDataController.initiliazeImageData()
                }
            }
        ]
    }

    states: [
        State {
            name: ""
            PropertyChanges {target: info; enabled: true}
            PropertyChanges {target: downloadingFile; visible: false}
            PropertyChanges {target: progressBar; visible: false}
            PropertyChanges {target: downloadMessage; visible: true}
        },

        State {
            name: "downloading"
            PropertyChanges {target: info; enabled: false}
            PropertyChanges {target: downloadingFile; visible: true}
            PropertyChanges {target: progressBar; visible: true}
            PropertyChanges {target: downloadMessage; visible: false}
        }
    ]
}
