/*
 * SPDX-FileCopyrightText: 2021 Dimitris Kardarakos <dimkard@posteo.net>
 *
 * SPDX-License-Identifier: GPL-3.0-or-later
 */

import QtQuick 2.12
import QtQuick.Controls 2.12 as Controls
import QtQuick.Layouts 1.12
import org.kde.kirigami 2.12 as Kirigami
import org.codeberg.dimkard.glossaico 1.0 as Glossaico

Kirigami.ScrollablePage {
    id: root

    property string skillName
    property string skillWordsAndPhrases
    property string skillImage
    property var specialCharacters
    property string targetLanguage
    property string courseName
    property int challengeIndex: 20
    property var challengePage

    title: skillName

    Connections {
        target: QPracticeContext

        function onContinueSession() {
            pageStack.pop(root)
            pageStack.push(challengePageContainer[QPracticeContext.currentChallengeQuestion.challengeType], {challengeData: QPracticeContext.currentChallengeQuestion, progress: QPracticeContext.practiceProgress() })
        }

        function onCompleteSession() {
            pageStack.pop(root)
            pageStack.push(challengeCompletePage)
        }
    }

    ColumnLayout {

        anchors {
            left: parent.left
            right: parent.right
            top: parent.top
            leftMargin: Kirigami.Units.largeSpacing
            rightMargin: Kirigami.Units.largeSpacing
            topMargin: Kirigami.Units.largeSpacing
        }

        spacing: Kirigami.Units.largeSpacing

        Kirigami.Heading {
            text: root.skillName
            wrapMode: Text.WordWrap

            Layout.fillWidth: true
        }

        Controls.Label {
            visible: root.skillWordsAndPhrases
            text: qsTr("Learn: %1").arg(root.skillWordsAndPhrases)
            wrapMode: Text.WordWrap

            Layout.fillWidth: true
        }

        RowLayout {
            spacing: Kirigami.Units.largeSpacing

            Controls.Button {
                text: qsTr("Back to Skills")

                onClicked: {
                    QPracticeContext.endPractice()
                    pageStack.pop()
                }
            }

            Controls.Button {
                text: qsTr("Practice %1").arg(root.skillName)

                onClicked: {
                    if(QPracticeContext.loadChallenge ()) {
                        pageStack.push(challengePageContainer[QPracticeContext.currentChallengeQuestion.challengeType], {challengeData: QPracticeContext.currentChallengeQuestion, progress: QPracticeContext.practiceProgress() })
                    }
                }
            }
        }

    }

    Component {
        id: challengeCompletePage
        ChallengeCompletePage {
            challengesAnswered: QPracticeContext.challengesAnswered

            onSessionEnd: {
                pageStack.pop()
                pageStack.removePage(root)
                QPracticeContext.endPractice()
            }
        }
    }

    ChallengePagesContainer {
        id: challengePageContainer

        targetLanguage: root.targetLanguage
        specialCharacters: root.specialCharacters
        courseName: root.courseName
    }
}
