/*
 * SPDX-FileCopyrightText: 2021 Dimitris Kardarakos <dimkard@posteo.net>
 *
 * SPDX-License-Identifier: GPL-3.0-or-later
 */

import QtQuick 2.12
import QtQuick.Controls 2.12 as Controls
import QtQuick.Layouts 1.12
import org.kde.kirigami 2.12 as Kirigami
import org.codeberg.dimkard.glossaico 1.0 as Glossaico

Kirigami.ScrollablePage {
    id: root

    property var specialCharacters: []
    property string targetLanguage
    property alias skills: skillsModel.skills
    property string courseName

    title: qsTr("Skills")

    Kirigami.PlaceholderMessage {
        anchors.centerIn: parent

        visible: view.count === 0
        width: parent.width - (Kirigami.Units.largeSpacing * 4)
        text: qsTr("No skill found")
    }

    Kirigami.CardsListView {
        id: view

        enabled: skillsModel && count > 0
        model: skillsModel

        delegate: Kirigami.AbstractCard {
            contentItem: Item {
                implicitWidth: delegateLayout.implicitWidth
                implicitHeight: Kirigami.Units.gridUnit * 4

                RowLayout {
                    id: delegateLayout

                    anchors {
                        left: parent.left
                        top: parent.top
                        right: parent.right
                    }
                    spacing: Kirigami.Units.largeSpacing

                    Image {
                        source: model.sample_image ? QConfigSingletonAdapter.dataDirectory + "/images/" + model.sample_image + "_tiny" : QConfigSingletonAdapter.applicationDirectory + "/icons/mascot-jetpack-noshadow.svg"

                        Layout.fillHeight: true
                        Layout.maximumHeight: Kirigami.Units.iconSizes.huge
                        Layout.preferredWidth: height
                    }

                    ColumnLayout {

                        RowLayout {
                            Kirigami.Icon {
                                visible: model.active_user_progress >= 1
                                implicitHeight: Kirigami.Units.iconSizes.smallMedium
                                source: "dialog-ok"
                            }

                            Kirigami.Heading {
                                level: 2
                                text: model.name
                            }
                        }

                        Controls.Label {
                            elide: Text.ElideRight
                            text: model.sample_words || model.sample_phrases

                            Layout.fillWidth: true
                        }

                        Controls.ProgressBar {
                            id: bar

                            from: 0
                            to: 1
                            visible: model.active_user_progress < 1
                            value: model.active_user_progress

                            Layout.fillWidth: true
                        }
                    }

                    Controls.Button {
                        text: model.active_user_progress < 1 ? qsTr("Learn") : qsTr("Review")

                        Layout.alignment: Qt.AlignRight|Qt.AlignVCenter
                        Layout.columnSpan: 2

                        onClicked: {
                            if(QPracticeContext.startPractice(root.courseName, model.skill_id, model.name, model.words, model.phrases, model.active_user_skill_stats)) { //user stats deserve their own class
                                pageStack.push(skillPage, {skillName: model.name, skillWordsAndPhrases: model.sample_words || model.sample_phrases, skillImage: model.sample_image})
                            }
                        }
                    }
                }
            }
        }

    }

    Component {
        id: skillPage

        SkillPage {
            specialCharacters: root.specialCharacters
            targetLanguage: root.targetLanguage
            courseName: root.courseName
        }
    }

    Glossaico.QSkillsModel {
        id: skillsModel
    }
}
