/*
 * SPDX-FileCopyrightText: 2021 Dimitris Kardarakos <dimkard@posteo.net>
 *
 * SPDX-License-Identifier: GPL-3.0-or-later
 */

import QtQuick 2.12
import QtQuick.Controls 2.12 as Controls
import org.kde.kirigami 2.12 as Kirigami
import QtQuick.Layouts 1.12
import org.codeberg.dimkard.glossaico 1.0 as Glossaico

Kirigami.ApplicationWindow
{
    id: root

    width: Kirigami.Units.gridUnit * 30

    globalDrawer: LLMGlobalDrawer {
        courses: coursesView
        pageStack: root.pageStack
        targetLanguage: languageCourse.targetLanguageName
        handleVisible: pageStack.currentItem && pageStack.currentItem.hasOwnProperty("showGlobalHandle") && pageStack.currentItem.showGlobalHandle
    }

    contextDrawer: Kirigami.ContextDrawer {}

    pageStack {
        defaultColumnWidth: Kirigami.Units.gridUnit * 40
        initialPage: QConfigSingletonAdapter.imagesReady ? coursesView : imageLoadPage
    }

    Component {
        id: coursesView

        CoursesView {

            course: languageCourse

            onCourseLoaded: {
                pageStack.clear()
                pageStack.push(modulesView)
            }
        }
    }

    Component {
        id: modulesView

        ModulesView {
            course: languageCourse
        }
    }

    Component {
        id: imageLoadPage

        ImageLoadPage {}
    }

    Glossaico.QLanguageCourse {
        id: languageCourse
    }

    Item {
        states: [
            State {
                name: ""
                PropertyChanges {target: pageStack; globalToolBar.style: Kirigami.ApplicationHeaderStyle.Auto}
                PropertyChanges {target: pageStack; interactive: true}
            },
            State {
                name: "prevent-navigation"
                when: QPracticeContext.practicing
                PropertyChanges {target: pageStack; globalToolBar.style: Kirigami.ApplicationHeaderStyle.None}
                PropertyChanges {target: pageStack; interactive: false}
            }
        ]
    }
}
